EventDrop

Enum EventDrop 

pub enum EventDrop {
    None,
    Manual {
        target_event_rate: f64,
        alpha: f64,
    },
    Auto,
}
Allow the encoder to randomly drop events before compressing, if the event rate is too high

Variants



None

Don’t drop any events



Manual

Randomly drop events according to this user-provided event rate

Fields

target_event_rate: f64
alpha: f64

The decay rate in [0., 1.]



Auto

TODO: Implement this. Query the actual network bandwidth accoring to some stream handle and drop events accordingly.