PlaneSize

Struct PlaneSize 

pub struct PlaneSize { /* private fields */ }
The size of the image plane in pixels

Implementations

Source

impl PlaneSize

pub fn new(width: u16, height: u16, channels: u8) -> Result<Self, PlaneError>

Create a new PlaneSize with the given width, height, and channels

pub fn w(&self) -> u16

The width, shorthand for self.width

pub fn w_usize(&self) -> usize

The height, shorthand for self.height

pub fn h(&self) -> u16

The height, shorthand for self.height

pub fn h_usize(&self) -> usize

The height, shorthand for self.height

pub fn c(&self) -> u8

The number of channels, shorthand for self.channels

pub fn c_usize(&self) -> usize

The number of channels, shorthand for self.channels

pub fn area_wh(&self) -> usize

The total number of 2D pixels in the image plane, across the height and width dimension

pub fn area_wc(&self) -> usize

The total number of 2D pixels in the image plane, across the width and channel dimension

pub fn area_hc(&self) -> usize

The total number of 2D pixels in the image plane, across the height and channel dimension

pub fn volume(&self) -> usize

The total number of 3D pixels in the image plane (2D pixels * color depth)

pub fn min_resolution(&self) -> u16

The smaller of the width and height dimensions

pub fn max_resolution(&self) -> u16

The larger of the width and height dimensions